@@ -18,7 +18,9 @@ try:
 except ImportError:
     import Tkinter as tkinter # Python 2
 
-from dragonlib.utils.logging_utils import log
+import logging
+
+log=logging.getLogger(__name__)
 from dragonpy.Dragon32.dragon_charmap import NORMAL, get_hex_color, COLORS, INVERTED
 
 
@@ -1215,7 +1217,7 @@ CHARS_DICT = {
 
 
 
-class TkFont(object):
+class TkImageFont(object):
     """
     Important is that image must be bind to a object, without:
     the garbage-collection by Python will "remove" the created images in Tkinter.Canvas!
@@ -1275,7 +1277,7 @@ class TkFont(object):
         return img
 
 
-class TestTkFont(object):
+class TestTkImageFont(object):
     CACHE = {}
     def __init__(self, row_count, tk_font, colors):
         self.row_count = row_count
@@ -1285,7 +1287,7 @@ class TestTkFont(object):
         self.current_color = self.colors[self.color_index]
 
         self.root = tkinter.Tk()
-        self.root.title("TkFont Test")
+        self.root.title("TkImageFont Test")
 
         self.root.bind('<Down>', self.event_arrow_down)
         self.root.bind('<Up>', self.event_arrow_up)
@@ -1365,13 +1367,13 @@ if __name__ == "__main__":
 #     scale_factor = 3
     scale_factor = 4
 #     scale_factor = 8
-    tk_font = TkFont(
+    tk_font = TkImageFont(
         CHARS_DICT, scale_factor,
     )
 
     colors = (NORMAL, INVERTED) + COLORS
 
-    t = TestTkFont(
+    t = TestTkImageFont(
         row_count=10,
         tk_font=tk_font,
         colors=colors,
