@@ -8,6 +8,7 @@
 """
 
 from __future__ import absolute_import, division, print_function
+from dragonlib.utils.unittest_utils import TextTestRunner2
 from dragonlib.utils import six
 xrange = six.moves.xrange
 
@@ -15,10 +16,7 @@ import logging
 import sys
 import unittest
 
-from dragonpy.tests.test_base import TextTestRunner2, BaseCPUTestCase
-from dragonlib.utils.logging_utils import setup_logging
-from dragonpy.tests.test_config import TestCfg
-from dragonpy.components.cpu6809 import CPU
+from dragonpy.tests.test_base import BaseCPUTestCase
 
 
 log = logging.getLogger("DragonPy")
