@@ -20,8 +20,10 @@ import logging
 import sys
 import unittest
 
+from dragonlib.utils.unittest_utils import TextTestRunner2
 from dragonlib.utils import six
-from dragonpy.tests.test_base import TextTestRunner2, BaseStackTestCase
+from dragonpy.tests.test_base import BaseStackTestCase
+
 
 log = logging.getLogger(__name__)
 
